@@ -3,7 +3,7 @@ package NumSeq::Iter;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-07-17'; # DATE
 our $DIST = 'NumSeq-Iter'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -125,7 +125,11 @@ sub numseq_parse {
     eval {
         $res = _numseq_parse_or_iter('parse', @_);
     };
-    if ($@) { return [400, "Parse fail: $@"] }
+    if ($@) {
+        my $errmsg = $@;
+        $errmsg =~ s/(.+) at .+/$1/s; # ux: remove file+line number information from error message
+        return [400, "Parse fail: $errmsg"];
+    }
     [200, "OK", $res];
 }
 
@@ -144,7 +148,7 @@ NumSeq::Iter - Generate a coderef iterator from a number sequence specification
 
 =head1 VERSION
 
-This document describes version 0.002 of NumSeq::Iter (from Perl distribution NumSeq-Iter), released on 2021-07-17.
+This document describes version 0.003 of NumSeq::Iter (from Perl distribution NumSeq-Iter), released on 2021-07-17.
 
 =head1 SYNOPSIS
 
